package Module::CPANTS::Site::View::TT;

use strict;
use warnings;

use base qw( Catalyst::View::TT );

1;

__END__

=head1 NAME

Module::CPANTS::Site::View::TT - TT View Component

=head1 SYNOPSIS

See L<Module::CPANTS::Site>

=head1 DESCRIPTION

TT View Component.

=head1 AUTHOR

Thomas Klausner, <domm@cpan.org>

=head1 LICENSE

This library is free software . You can redistribute it and/or modify
it under the same terms as perl itself.

=cut
